<?php
class pluginSecureAccessPlus extends Plugin {
    public function init() {
        $this->dbFields = [
            "passwords" => [],
            "backgroundColor" => "#1c2022",
            "buttonColor" => "secondary",
            "buttonText" => "Login",
            "inputText" => "Enter Password"
        ];
    }
    public function beforeAll() {
        global $url, $login;
        session_start();
        if (isset($login) && $login->isLogged()) {
            return;
        }
        $passwords = $this->db['passwords'];
        if (isset($_POST['password']) && in_array($_POST['password'], $passwords)) {
            $_SESSION['password_protected_login'] = true;
            header('Location: ' . $this->uri());
            exit;
        }
        if (!isset($_SESSION['password_protected_login'])) {
            $this->loginForm();
            exit;
        }
    }
    private function loginForm() {
        $title = str_replace('<title>', '<title>[Login Required] ', Theme::metaTags('title'));
        $bootstrapPath = $this->htmlPath().'css/bootstrap.min.css';
        $backgroundColor = $this->getValue('backgroundColor');
        $buttonColor = $this->getValue('buttonColor');
        $buttonText = $this->getValue('buttonText');
        $inputText = $this->getValue('inputText');
        echo <<<HTML
<html>
<head>
{$title}
<link rel="stylesheet" href="{$bootstrapPath}">
<style>
    body { background-color: {$backgroundColor}; }
</style>
</head>
<body>
    <div class="container d-flex align-items-center justify-content-center" style="height: 100vh;">
        <div class="row w-100">
            <div class="col-md-10 offset-md-1 col-lg-8 offset-lg-2 col-xl-6 offset-xl-3">
                <form method="post" class="input-group input-group-lg">
                    <input type="password" class="form-control" name="password" placeholder="{$inputText}" autofocus>
                    <button class="btn btn-{$buttonColor}" type="submit">{$buttonText}</button>
                </form>
            </div>
        </div>
    </div>
</body>
</html>
HTML;
        exit;
    }
    public function adminBodyEnd() {
        return '<script src="' . $this->htmlPath() . 'js/jscolor.min.js"></script>';
    }
    public function form() {
        $passwords = $this->db['passwords'];
        $backgroundColor = htmlspecialchars($this->getValue('backgroundColor'));
        $buttonColor = htmlspecialchars($this->getValue('buttonColor'));
        $buttonText = htmlspecialchars($this->getValue('buttonText'));
        $inputText = htmlspecialchars($this->getValue('inputText'));
        $buttonColors = ["primary", "secondary", "success", "danger", "warning", "info", "light", "dark"];
        ?>
        <div class="form-group">
            <label for="passwords">Enter passwords, one per line:</label>
            <textarea id="passwords" name="passwords" rows="10" style="width: 100%;"><?php echo implode("\n", $passwords); ?></textarea>
        </div>
        <div class="form-group">
            <label for="backgroundColor">Background Color:</label>
            <input type="text" name="backgroundColor" class="jscolor" value="<?php echo $backgroundColor; ?>">
        </div>
        <div class="form-group">
            <label for="buttonColor">Button Color (Bootstrap classes):</label>
            <select name="buttonColor">
                <?php foreach ($buttonColors as $color): ?>
                    <option value="<?php echo $color; ?>" <?php echo ($color === $buttonColor) ? "selected" : ""; ?>><?php echo ucfirst($color); ?></option>
                <?php endforeach; ?>
            </select>
        </div>
        <div class="form-group">
            <label for="buttonText">Login Button Text:</label>
            <input type="text" name="buttonText" value="<?php echo $buttonText; ?>">
        </div>
        <div class="form-group">
            <label for="inputText">Login Input Text:</label>
            <input type="text" name="inputText" value="<?php echo $inputText; ?>">
        </div>
        <button type="submit" class="btn btn-primary">Save</button>
        <?php
    }
    public function post() {
        if (isset($_POST['passwords'])) {
            $passwords = array_filter(array_map('trim', explode("\n", $_POST['passwords'])));
            $this->db['passwords'] = $passwords;
        }
        $this->db['backgroundColor'] = $_POST['backgroundColor'] ?? '#1c2022';
        $this->db['buttonColor'] = $_POST['buttonColor'] ?? 'secondary';
        $this->db['buttonText'] = $_POST['buttonText'] ?? 'Login';
        $this->db['inputText'] = $_POST['inputText'] ?? 'Enter Password';
        $this->save();
    }
}
